Added resources to the platform description, fixed link in querytable for the init_ke...
[myslice.git] / setup.py
index b9b1a75..e7ab6a5 100644 (file)
--- a/setup.py
+++ b/setup.py
@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
# Setup script for myslice
 #
 # Thierry Parmentelat <thierry.parmentelat@inria.fr>
 # INRIA (c) 2013
@@ -13,6 +13,7 @@ from distutils.core import setup
 packages= [ os.path.dirname(init) for init in (glob("*/__init__.py")+glob("*/*/__init__.py")) ]
 
 setup(packages = packages,
+      # xxx somehow this does not seem to show up in debian packaging
       scripts = [ 'apache/unfold-init-ssl.sh' ],
       data_files = [ 
         ( '/usr/share/unfold/static/js', glob ('static/js/*')),
@@ -20,5 +21,5 @@ setup(packages = packages,
         ( '/usr/share/unfold/static/img', glob ('static/img/*')),
         ( '/usr/share/unfold/static/fonts', glob ('static/fonts/*')),
         ( '/usr/share/unfold/templates', glob ('templates/*')),
-        ( 'apache', [ 'apache/myslice.conf' ]),
+        ( 'apache', [ 'apache/unfold.conf', 'apache/unfold.wsgi' ]),
         ])
@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Setup script for myslice
+# Setup script for myslice+unfold
 #
 # Thierry Parmentelat <thierry.parmentelat@inria.fr>